# -*- coding: utf-8 -*-
import numpy as np
import math
mesh_size=1168
filename='X_1p32Bohr.upf'
Qtot = 1
sigma = 1.32



mesh=np.linspace(0,(float(mesh_size-1))/100,num=mesh_size)

Vlocal = np.zeros(mesh_size)

for i in range(mesh_size-1):
	Vlocal[i+1]=-2*Qtot*math.erf(mesh[i+1]/(math.sqrt(2)*sigma))/mesh[i+1]
Vlocal[0]=Vlocal[1]

rhoatom = np.zeros(mesh_size)

for i in range(mesh_size):
	rhoatom[i]=(Qtot/np.power((2*math.pi*np.power(sigma,2)),3./2.))*np.exp(-np.power(mesh[i],2)/(2*np.power(sigma,2)))
	
scaled_rhoatom = np.zeros(mesh_size)
for i in range(mesh_size):
	scaled_rhoatom[i]=4*math.pi*np.power(mesh[i],2)*rhoatom[i]
	
f = open(filename,'w')
f.write(' <UPF version="2.0.1">   \r\n')
f.write(' <PP_INFO>   \r\n')
f.write(' # Generated PP for artificial atom:    \r\n')
f.write(' # sigma='+str(sigma)+' \r\n')
f.write(' #   \r\n')
f.write(' </PP_INFO>   \r\n')
f.write(' <PP_HEADER   \r\n')
f.write(' generated=""   \r\n')
f.write(' author=""   \r\n')	
f.write(' date=""   \r\n')
f.write(' comment=""   \r\n')
f.write(' element="H "   \r\n')
f.write(' pseudo_type="NC"   \r\n')
f.write(' relativistic="scalar"   \r\n')
f.write(' is_ultrasoft="F"   \r\n')
f.write(' is_paw="F"   \r\n')
f.write(' is_coulomb="F"   \r\n')
f.write(' has_so="F"   \r\n')
f.write(' has_wfc="F"   \r\n')
f.write(' has_gipaw="F"   \r\n')
f.write(' core_correction="F"   \r\n')
f.write(' functional="PBE"   \r\n')
f.write(' z_valence="   '+str(Qtot)+'.0"   \r\n')
f.write(' total_psenergy="  -1.0"   \r\n')
f.write(' rho_cutoff="   '+str(mesh_size/1000)+'"   \r\n')
f.write(' l_max="0"   \r\n')
f.write(' l_local="-1"   \r\n')
f.write(' mesh_size="  '+str(mesh_size)+'"   \r\n')
f.write(' number_of_wfc="0"   \r\n')
f.write(' number_of_proj="0"/>   \r\n')
f.write(' <PP_MESH>   \r\n')
f.write(' <PP_R type="real"  size="'+str(mesh_size)+'" columns="8">   \r\n')

num_format = "{:.4f}".format
for i in range(int(mesh_size/8)):
	f.write(' '+num_format(mesh[8*i])+'   '+num_format(mesh[8*i+1])+'   '+num_format(mesh[8*i+2])+'   '+num_format(mesh[8*i+3])+'   '+num_format(mesh[8*i+4])+'   '+num_format(mesh[8*i+5])+'   '+num_format(mesh[8*i+6])+'   '+num_format(mesh[8*i+7])+'   \r\n')
	

f.write(' </PP_R>   \r\n')
f.write(' <PP_RAB type="real"  size="'+str(mesh_size)+'" columns="8">   \r\n')
for i in range(int(mesh_size/8)):
	f.write(' 0.0100   0.0100   0.0100   0.0100   0.0100   0.0100   0.0100   0.0100   \r\n')
f.write(' </PP_RAB>   \r\n')
f.write(' </PP_MESH>   \r\n')
f.write(' <PP_LOCAL type="real"  size="'+str(mesh_size)+'" columns="4">   \r\n')

num_format = "{:.10f}".format
for i in range(int(mesh_size/4)):
	f.write(' '+num_format(Vlocal[4*i])+'   '+num_format(Vlocal[4*i+1])+'   '+num_format(Vlocal[4*i+2])+'   '+num_format(Vlocal[4*i+3])+'   \r\n')
f.write(' </PP_LOCAL>   \r\n')
f.write(' <PP_NONLOCAL>   \r\n')
f.write(' </PP_NONLOCAL>   \r\n')
f.write(' <PP_PSWFC>   \r\n')
f.write(' </PP_PSWFC>   \r\n')
f.write(' <PP_RHOATOM type="real"  size="'+str(mesh_size)+'" columns="4">   \r\n')

num_format = "{:.10e}".format
for i in range(int(mesh_size/4)):
	f.write(' '+num_format(scaled_rhoatom[4*i])+'   '+num_format(scaled_rhoatom[4*i+1])+'   '+num_format(scaled_rhoatom[4*i+2])+'   '+num_format(scaled_rhoatom[4*i+3])+'   \r\n')

f.write(' </PP_RHOATOM>   \r\n')
f.write(' </UPF>   \r\n')
f.write(' END_PSP   \r\n')
f.close()
